/***********************************************
 **  TheClock - v0.8.1 - 5/7/98, Andreas Raquet **
 ***********************************************/

#ifndef THECLOCK_H
#define THECLOCK_H 

#include <Be.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <parsedate.h>
#include "MButton.h"
#include "HGroup.h"
#include "VGroup.h"
#include "MBViewWrapper.h"
#include "MWindow.h"
#include "MPopup.h"
#include "MBorder.h"
#include "Preferences.h"
#include "FFont.h"
#include "Colors.h"

#define signature "application/x-vnd.raquet-theclock"

void DrawPointer(BView* target, BPoint center, float angle, float factor, float backFactor, float widthFactor);

class __declspec(dllexport) TheClockView : public BView
{
public:
	TheClockView( BRect frame, const char* name, uint32 resizingMode, uint32 flags);
	TheClockView( BMessage *msg);
	~TheClockView();
	virtual status_t Archive(BMessage* data, bool deep) const;
	virtual void MessageReceived(BMessage* msg);
	static TheClockView* Instantiate(BMessage* data);
	void initialize();
	void Draw(BRect bounds);
	void Pulse();
	void MouseDown(BPoint point);
	void FrameResized(float width, float height);
	void SetBackImage(BBitmap *bitmap, char* fileName);
	bool loadSettings();
	void SetMenu();
	bool ownWindow;
	friend class TheClockPainter;
	friend class TheClockConfig;
	friend void DrawClock(BView *target, TheClockView *source);
	
private:	
	struct tm*		timeRecord;	 
	void			SaveConfig();
	void			saveSettings();
	BBitmap*		bitmap;
	BBitmap*		bgBitmap;
	char			bgFilename[B_FILE_NAME_LENGTH];
	TheClockPainter*	painter;
	BPopUpMenu*		menu;
	rgb_color		bgColor;
	rgb_color		fgColor;
	rgb_color		shadowColor;
	rgb_color		secColor;
	BFont			timeFont;
	BFont			secondFont;
	char			timeText[10];
	char			secondText[3];
	bool			resizing;
	bool			showSeconds;
	bool			digitalClock;
	bool			alwaysOnTop;
	bool			castShadow;
	bool			doBeep;
	bool			onmenu;
	bool			showBorders;
	bool			minuteDots;
	int 			bgType;
	BMenuItem*		showSecondsItem;
	BMenuItem*		digitalClockItem;
	BMenuItem*		alwaysOnTopItem;
	BMenuItem*		doBeepItem;
	BMenuItem*		castShadowItem;
	BMenuItem*		showBordersItem;
	BMenuItem*		bgImageItem;
	BMenuItem*		configureItem;
	BMenuItem*		minuteDotItem;
	BMenuItem*		saveItem;
	sem_id sid;
};

class TheClockPainter : public BView {
public:
	 TheClockPainter(BRect frame, TheClockView* p);
	 ~TheClockPainter();
	 void FillBitmap();
	 TheClockView *clockView;
	 };
	 
class TheClockConfig : public MWindow {
public:
	TheClockConfig(BRect frame, TheClockView* clock);	 
	~TheClockConfig();
	void MessageReceived(BMessage *msg);
private:
	TheClockView* clockView;
	MPopup* fontStyle;
	MPopup* colorType;
	MPopup* bgType;
	BColorControl* colorChooser;
};

class TheClockWindow : public BWindow {
public:
	TheClockWindow();
	~TheClockWindow();
	bool QuitRequested();
	TheClockView* clockView;
private:
	BDragger *dragger;
};

class TheClock : public BApplication {
public:
	TheClock();
private:
	TheClockWindow* win;
};

#define FONT_FAMILY  'TCFF'
#define FONT_STYLE	 'TCFS'
#define FONT_SIZE    'TCFH'
#define COLOR_TYPE   'TCCT'
#define BG_TYPE      'TCBT'
#define SELECT_IMAGE 'TCSI'
#define COLOR_CHANGE 'TCCC'

#define BG_NONE		'TCBN'
#define BG_PATTERN	'TCBP'
#define BG_PICTURE	'TCBI'

#define SHOW_SECONDS	'TCSS'
#define MINUTE_DOTS 	'TCMD'
#define ON_TOP			'TCOT'
#define DIGITAL			'TCDI'
#define DO_BEEP			'TCDB'
#define CAST_SHADOW		'TCCS'
#define SHOW_BORDERS	'TCSB'
#define CONFIGURE		'TCCN'
#define SAVE			'TCSV'

#endif
